@@ -8,13 +8,17 @@ from dataclasses import (  # type: ignore
 )
 from typing import Mapping, Type, TypeVar
 
-if sys.version_info <= (3, 7):
+if sys.version_info <= (3, 7):  # pragma: no cover
     is_dataclass_ = is_dataclass
 
     def is_dataclass(obj) -> bool:
         return is_dataclass_(obj) and getattr(obj, "__origin__", None) is None
 
 
+def is_dataclass_origin(cls: Type) -> bool:
+    return is_dataclass(getattr(cls, "__origin__", cls))
+
+
 T = TypeVar("T")
 
 
